[PATCH 3/7] core: rename notify_changed by notify_change



Signed-off-by: Juan A. Suarez Romero <jasuarez igalia com>
---
 src/grl-media-source.c    |   34 +++++++++++++++++-----------------
 src/grl-media-source.h    |   22 +++++++++++-----------
 src/grl-metadata-source.h |    4 ++--
 3 files changed, 30 insertions(+), 30 deletions(-)

diff --git a/src/grl-media-source.c b/src/grl-media-source.c
index 7f3b3b6..2548f0f 100644
--- a/src/grl-media-source.c
+++ b/src/grl-media-source.c
@@ -2043,8 +2043,8 @@ grl_media_source_supported_operations (GrlMetadataSource *metadata_source)
   if (media_source_class->test_media_from_uri &&
       media_source_class->media_from_uri)
     caps |= GRL_OP_MEDIA_FROM_URI;
-  if (media_source_class->notify_changed_start)
-    caps |= GRL_OP_NOTIFY_CHANGED;
+  if (media_source_class->notify_change_start)
+    caps |= GRL_OP_NOTIFY_CHANGE;
 
   return caps;
 }
@@ -2536,7 +2536,7 @@ grl_media_source_get_media_from_uri_sync (GrlMediaSource *source,
 }
 
 /**
- * grl_media_source_notify_changed_start:
+ * grl_media_source_notify_change_start:
  * @source: a media source
  * @error: a #GError, or @NULL
  *
@@ -2547,38 +2547,38 @@ grl_media_source_get_media_from_uri_sync (GrlMediaSource *source,
  * Returns: @TRUE if initialization has succeed.
  */
 gboolean
-grl_media_source_notify_changed_start (GrlMediaSource *source,
-                                       GError **error)
+grl_media_source_notify_change_start (GrlMediaSource *source,
+                                      GError **error)
 {
   g_return_val_if_fail (GRL_IS_MEDIA_SOURCE (source), FALSE);
   g_return_val_if_fail (grl_media_source_supported_operations (GRL_METADATA_SOURCE (source)) &
-                        GRL_OP_NOTIFY_CHANGED, FALSE);
+                        GRL_OP_NOTIFY_CHANGE, FALSE);
 
-  return GRL_MEDIA_SOURCE_GET_CLASS (source)->notify_changed_start (source,
-                                                                    error);
+  return GRL_MEDIA_SOURCE_GET_CLASS (source)->notify_change_start (source,
+                                                                   error);
 }
 
 /**
- * grl_media_source_notify_changed_stop:
+ * grl_media_source_notify_change_stop:
  * @source: a media source
  *
  * This will drop emission of ::content-changed signals from @source. When this
  * is done @source should stop the machinery required for it to track changes in
  * the content.
  */
-void grl_media_source_notify_changed_stop (GrlMediaSource *source)
+void grl_media_source_notify_change_stop (GrlMediaSource *source)
 {
   g_return_if_fail (GRL_IS_MEDIA_SOURCE (source));
 
   GrlMediaSourceClass *source_class = GRL_MEDIA_SOURCE_GET_CLASS (source);
 
-  if (source_class->notify_changed_stop) {
-    source_class->notify_changed_stop (source);
+  if (source_class->notify_change_stop) {
+    source_class->notify_change_stop (source);
   }
 }
 
 /**
- * grl_media_source_notify_changed:
+ * grl_media_source_notify_change:
  * @source: a media source
  * @media: (allow-none): the media which has changed
  * @change_type: the type of change
@@ -2595,10 +2595,10 @@ void grl_media_source_notify_changed_stop (GrlMediaSource *source)
  *  </para>
  * </note>
  */
-void grl_media_source_notify_changed (GrlMediaSource *source,
-                                      GrlMedia *media,
-                                      GrlMediaSourceChangeType change_type,
-                                      gboolean location_unknown)
+void grl_media_source_notify_change (GrlMediaSource *source,
+                                     GrlMedia *media,
+                                     GrlMediaSourceChangeType change_type,
+                                     gboolean location_unknown)
 {
   g_return_if_fail (GRL_IS_MEDIA_SOURCE (source));
   g_return_if_fail (!media || GRL_IS_MEDIA (media));
diff --git a/src/grl-media-source.h b/src/grl-media-source.h
index 4c7f6e7..d6a61e1 100644
--- a/src/grl-media-source.h
+++ b/src/grl-media-source.h
@@ -365,8 +365,8 @@ typedef struct _GrlMediaSourceClass GrlMediaSourceClass;
  * instances from a given URI.
  * @media_from_uri: Creates a #GrlMedia instance representing the media
  * exposed by a certain URI.
  * @notify_changed_start: start emitting signals about changes in content
  * @notify_changed_stop: stop emitting signals about changes in content
  *
  * Grilo MediaSource class. Override the vmethods to implement the
  * source functionality.
@@ -397,10 +397,10 @@ struct _GrlMediaSourceClass {
   void (*media_from_uri) (GrlMediaSource *source,
 			  GrlMediaSourceMediaFromUriSpec *mfss);
 
-  gboolean (*notify_changed_start) (GrlMediaSource *source,
+  gboolean (*notify_change_start) (GrlMediaSource *source,
                                     GError **error);
 
-  void (*notify_changed_stop) (GrlMediaSource *source);
+  void (*notify_change_stop) (GrlMediaSource *source);
 
   /*< private >*/
   gpointer _grl_reserved[GRL_PADDING];
@@ -531,15 +531,15 @@ GrlMedia *grl_media_source_get_media_from_uri_sync (GrlMediaSource *source,
                                                     GrlMetadataResolutionFlags flags,
                                                     GError **error);
 
-gboolean grl_media_source_notify_changed_start (GrlMediaSource *source,
-                                                GError **error);
+gboolean grl_media_source_notify_change_start (GrlMediaSource *source,
+                                               GError **error);
 
-void grl_media_source_notify_changed_stop (GrlMediaSource *source);
+void grl_media_source_notify_change_stop (GrlMediaSource *source);
 
-void grl_media_source_notify_changed (GrlMediaSource *source,
-                                      GrlMedia *media,
-                                      GrlMediaSourceChangeType change_type,
-                                      gboolean location_unknown);
+void grl_media_source_notify_change (GrlMediaSource *source,
+                                     GrlMedia *media,
+                                     GrlMediaSourceChangeType change_type,
+                                     gboolean location_unknown);
 
 G_END_DECLS
 
@@ -365,8 +365,8 @@ typedef struct _GrlMediaSourceClass GrlMediaSourceClass;
  * @media_from_uri: Creates a #GrlMedia instance representing the media
  * exposed by a certain URI.
- * @notify_changed_start: start emitting signals about changes in content
- * @notify_changed_stop: stop emitting signals about changes in content
+ * @notify_change_start: start emitting signals about changes in content
+ * @notify_change_stop: stop emitting signals about changes in content
  *
  * Grilo MediaSource class. Override the vmethods to implement the
diff --git a/src/grl-metadata-source.h b/src/grl-metadata-source.h
index 3da29e9..51e0b4e 100644
--- a/src/grl-metadata-source.h
+++ b/src/grl-metadata-source.h
@@ -205,7 +205,7 @@ typedef struct {
  * @GRL_OP_SET_METADATA: Update metadata of a #GrlMedia in a service.
  * @GRL_OP_MEDIA_FROM_URI: Create a #GrlMedia instance from an URI
  * representing a media resource.
  * @GRL_OP_NOTIFY_CHANGED: Notify about changes in the #GrlMediaSource.
  *
  * Bitwise flags which reflect the kind of operations that a
  * #GrlMediaPlugin supports.
@@ -222,7 +222,7 @@ typedef enum {
   GRL_OP_REMOVE          = 1 << 7,
   GRL_OP_SET_METADATA    = 1 << 8,
   GRL_OP_MEDIA_FROM_URI  = 1 << 9,
-  GRL_OP_NOTIFY_CHANGED  = 1 << 10,
+  GRL_OP_NOTIFY_CHANGE   = 1 << 10,
 } GrlSupportedOps;
 
 /* GrlMetadataSource class */
@@ -205,7 +205,7 @@ typedef struct {
  * @GRL_OP_MEDIA_FROM_URI: Create a #GrlMedia instance from an URI
  * representing a media resource.
- * @GRL_OP_NOTIFY_CHANGED: Notify about changes in the #GrlMediaSource.
+ * @GRL_OP_NOTIFY_CHANGE: Notify about changes in the #GrlMediaSource.
  *
  * Bitwise flags which reflect the kind of operations that a
-- 
1.7.3.5



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]